@@ -3,13 +3,20 @@ use strict;
 use warnings;
 use Benchmark qw/cmpthese/;
 
-cmpthese(200000, {
+cmpthese(100000, {
+    'SM::A'      => sub {Mock::SMA->call({name => 'nekokak'})},
     'P::V'       => sub {Mock::PV->call(name => 'nekokak')},
     'S::A'       => sub {Mock::SA->call({name => 'nekokak'})},
     'S::A_fast'  => sub {Mock::SA->call_fast({name => 'nekokak'})},
-    'S::A_fast2' => sub {Mock::SA->call_fast2({name => 'nekokak'})},
 });
 
+package Mock::SMA;
+use Smart::Args;
+
+sub call {
+    args my $self, my $name;
+}
+
 package Mock::PV;
 use Params::Validate qw(:all);
 
@@ -27,17 +34,13 @@ sub call {
 }
 
 sub call_fast {
-    my $args = args({name => 1}, @_);
-}
-
-sub call_fast2 {
     shift;
     my $args = args({name => 1}, @_);
 }
 
 __END__
-               Rate       P::V       S::A S::A_fast2  S::A_fast
-P::V        50125/s         --       -66%       -79%       -80%
-S::A       147059/s       193%         --       -39%       -43%
-S::A_fast2 240964/s       381%        64%         --        -6%
-S::A_fast  256410/s       412%        74%         6%         --
+              Rate      P::V     SM::A      S::A S::A_fast
+P::V       46729/s        --      -55%      -61%      -78%
+SM::A     103093/s      121%        --      -13%      -52%
+S::A      119048/s      155%       15%        --      -44%
+S::A_fast 212766/s      355%      106%       79%        --
